%% histograms and first attempt at printing basic statistical values
% load data
data = load('lobo_data_subset.txt');

% data contains:
% 1 - oxygen [ml/l]
% 2 - fluorescence [micro g/l]   
% 3 - nitrate [micro M]  
% 4 - salinity
% 5 - days since 2001-1-1 [UTC]

% assign columns of data to individual variables - easier to work with
% and variable names are clearer
nit = data(:,3); sal = data(:,4); chl = data(:,2);

% histogram of nitrate data, 50 bins
figure(1)
hist(nit,50)
xlabel('nitrate [micro M]')
ylabel('number of data points per bin')

% histogram of salinity data in new figure window, 50 bins
figure(2)
hist(sal,50)
xlabel('salinity [psu]')
ylabel('number of data points per bin')

% histogram of chl fluorescence in another new figure window, 50 bins
figure(3)
hist(chl,50)
xlabel('chl fluorescence [micro g/l]')
ylabel('number of data points per bin')

% calculate the mean, median, variance of each variable
nit_mean = mean(nit); nit_med = median(nit); nit_var = var(nit);
sal_mean = mean(sal); sal_med = median(sal); sal_var = var(sal);
chl_mean = mean(chl); chl_med = median(chl); chl_var = var(chl);

% print out their value
fprintf('Nitrate mean: %.2f, median: %.2f, variance: %.3f\n',...
    nit_mean, nit_med, nit_var)
fprintf('Salinity mean: %.2f, median: %.2f, variance: %.3f\n',...
    sal_mean, sal_med, sal_var)
fprintf('Chlorophyll mean: %.2f, median: %.2f, variance: %.3f\n\n',...
    chl_mean, chl_med, chl_var)


%% filter out NaN values and print new results
% get indices that are nan
nit_bad = isnan(nit); nit(nit_bad) = [];
sal_bad = isnan(sal); sal(sal_bad) = [];
chl_bad = isnan(chl); chl(chl_bad) = [];

% re-calculate the statistical properties
nit_mean = mean(nit); nit_med = median(nit); nit_var = var(nit);
sal_mean = mean(sal); sal_med = median(sal); sal_var = var(sal);
chl_mean = mean(chl); chl_med = median(chl); chl_var = var(chl);

% print them, as above
fprintf('Nitrate mean: %.2f, median: %.2f, variance: %.3f\n',...
    nit_mean, nit_med, nit_var)
fprintf('Salinity mean: %.2f, median: %.2f, variance: %.3f\n',...
    sal_mean, sal_med, sal_var)
fprintf('Chlorophyll mean: %.2f, median: %.2f, variance: %.3f\n\n',...
    chl_mean, chl_med, chl_var)
